@@ -11,6 +11,7 @@
 ##' @param x temporally regularized location data, eg. output from \code{fit_ssm}
 ##' @param model specify whether MPM is to be fit with unpooled ("mpm") or pooled ("jmpm") RW variance(s). 
 ##' @param optim numerical optimizer to be used ("nlminb" or "optim")
+##' @param optMeth optimization method to use (default is "L-BFGS-B"), ignored if optim = "nlminb"
 ##' @param verbose report progress during minimization
 ##' @param control list of control parameters for the outer optimization (type ?nlminb or ?optim for details)
 ##' @param inner.control list of control settings for the inner optimization
@@ -20,19 +21,20 @@
 ##' @importFrom dplyr mutate arrange "%>%" count
 ##' @importFrom tibble tibble
 ##' @importFrom stats plogis median
-##'
-##' @export
+##' @keywords internal
 
 mpmf <-
   function(x,
            model = c("mpm", "jmpm"),
            optim = c("nlminb", "optim"),
-           verbose = FALSE,
+           optMeth = c("L-BFGS-B", "BFGS", "Nelder-Mead", "CG", "SANN", "Brent"),
+           verbose = TRUE,
            control = NULL,
            inner.control = NULL) {
     
     call <- match.call()
     optim <- match.arg(optim)
+    optMeth <- match.arg(optMeth)
     model <- match.arg(model)
     
     ## populate control list if any parameters specified...
@@ -101,53 +103,82 @@ mpmf <-
                              )
                            })
     
-##    rnd <- switch(model, mpm = "lg", jmpm = c("lg","log_sigma_g"))
-    
     ## TMB - create objective function
     if (is.null(inner.control) | !"smartsearch" %in% names(inner.control)) {
       inner.control <- list(smartsearch = TRUE)
     }
     
+    verb <- ifelse(verbose == 2, TRUE, FALSE)
+    rnd <- switch(model, jmpm = "lg", mpm = "lg")
+
     obj <-
       MakeADFun(
         data = data.tmb,
         parameters = parameters,
-        random = "lg",
+        random = rnd,
         DLL = "foieGras",
-        silent = !verbose,
+        silent = !verb,
         inner.control = inner.control
       )
     
+    obj$env$tracemgc <- verb
+    
     ## add par values to trace if verbose = TRUE
     myfn <- function(x) {
-      print(x)
+      cat("\r", "pars:  ", round(x, 5), "     ")
+      flush.console()
       obj$fn(x)
     }
     
-    ## Minimize objective function
-    opt <-
-      suppressWarnings(switch(optim,
-                              nlminb = try(nlminb(obj$par,
-                                                  obj$fn,
-                                                  #myfn,
-                                                  obj$gr,
-                                                  control = control
-                              )),
-                              optim = try(do.call(
-                                optim,
-                                args = list(
-                                  par = obj$par,
-                                  fn = obj$fn,
-                                  #fn = myfn,
-                                  gr = obj$gr,
-                                  method = "L-BFGS-B",
-                                  control = control
-                                )
-                              ))))
-
+    ## Set parameter bounds - most are -Inf, Inf
+    L = c(log_sigma=c(-10,-10),
+          log_sigma_g=-10
+          )
+    U = c(log_sigma=c(50,50),
+          log_sigma_g=50
+          )
+    names(L) <- c("log_sigma", "log_sigma", "log_sigma_g")
+    names(U) <- c("log_sigma", "log_sigma", "log_sigma_g")
     
+#    if(model == "jmpm") map <- list(log_sigma_g = factor(NA))
+    
+    # Remove inactive parameters from bounds
+    L <- L[!names(L) %in% names(map)]
+    U <- U[!names(U) %in% names(map)]
+    
+    ## Minimize objective function
+    oldw <- getOption("warn")
+    options(warn = -1)  ## turn warnings off but check if optimizer crashed & return warning at end
+    opt <-
+      switch(optim,
+             nlminb = try(nlminb(obj$par,
+                                 ifelse(verbose == 1, myfn, obj$fn),
+                                 obj$gr,
+                                 control = control,
+                                 lower = L,
+                                 upper = U
+             )), 
+             optim = try(do.call(
+               optim,
+               args = list(
+                 par = obj$par,
+                 fn = ifelse(verbose == 1, myfn, obj$fn),
+                 gr = obj$gr,
+                 method = optMeth,
+                 control = control,
+                 lower = L,
+                 upper = U
+               )
+             ), silent = TRUE))
+    cat("\n")
+    
+    ## if error then exit with limited output to aid debugging
+    ## check if pdHess is FALSE at end and return warning
+    rep <- try(sdreport(obj))
+    
+    options(warn = oldw) ## turn warnings back on
+
     ## Parameters, states and the fitted values
-    rep <- suppressWarnings(try(sdreport(obj, getReportCovariance = TRUE)))
     fxd <- summary(rep, "report")
     fxd_log <- summary(rep, "fixed")
     rdm <- summary(rep, "random")
